"""Helper functions for processing and manipulating response content.

This module contains utility functions designed to assist in the handling and
modification of response content generated by the language model. These functions
are crucial for maintaining the integrity and usability of the responses, ensuring
that they conform to the expected format and are free from unnecessary tags or
elements.
"""


def remove_think_tags(response_content: str) -> str:
    """
    Remove the content enclosed within <think> and </think> tags from the response content.

    Args:
        response_content (str): The original response content potentially containing <think> tags.

    Returns:
        str: The response content with <think> and </think> tags and their content removed.
    """
    if "<think>" in response_content:
        start_think_index = response_content.find("<think>")
        end_think_index = response_content.rfind("</think>")
        if start_think_index != -1 and end_think_index != -1:
            response_content = (
                response_content[:start_think_index]
                + response_content[end_think_index + len("</think>") :].strip()
            )
    return response_content
